--- res_features.c.backup	2006-02-09 11:23:53.000000000 -0500
+++ res_features.c	2006-02-15 12:49:53.000000000 -0500
@@ -663,6 +663,94 @@
 	return FEATURE_RETURN_SUCCESS;
 }
 
+static int builtin_autopark(struct ast_channel *chan, struct ast_channel *peer, struct ast_bridge_config *config, char *code, int sense)
+{
+	struct ast_channel *transferer;
+	struct ast_channel *transferee;
+	char *transferer_real_context;
+	char newext[256];
+	int res;
+
+	if (sense == FEATURE_SENSE_PEER) {
+		transferer = peer;
+		transferee = chan;
+	} else {
+		transferer = chan;
+		transferee = peer;
+	}
+	if (!(transferer_real_context = pbx_builtin_getvar_helper(transferee, "TRANSFER_CONTEXT")) &&
+	   !(transferer_real_context = pbx_builtin_getvar_helper(transferer, "TRANSFER_CONTEXT"))) {
+		/* Use the non-macro context to transfer the call */
+		if (!ast_strlen_zero(transferer->macrocontext))
+			transferer_real_context = transferer->macrocontext;
+		else
+			transferer_real_context = transferer->context;
+	}
+	/* Start autoservice on chan while we talk
+	   to the originator */
+	ast_indicate(transferee, AST_CONTROL_HOLD);
+	ast_autoservice_start(transferee);
+	ast_moh_start(transferee, NULL);
+	
+
+	/* Transfer */
+	if ((res=ast_waitstream(transferer, AST_DIGIT_ANY)) < 0) {
+		ast_moh_stop(transferee);
+		ast_autoservice_stop(transferee);
+		ast_indicate(transferee, AST_CONTROL_UNHOLD);
+		return res;
+	} else if (res > 0) {
+		newext[0] = (char) res;
+	}
+
+	ast_stopstream(transferer); 
+	if (res < 0) {
+		ast_moh_stop(transferee);
+		ast_autoservice_stop(transferee);
+		ast_indicate(transferee, AST_CONTROL_UNHOLD);
+		return res;
+	}
+	
+	ast_moh_stop(transferee);
+
+	res = ast_autoservice_stop(transferee);
+	ast_indicate(transferee, AST_CONTROL_UNHOLD);
+	if (res)
+		res = -1;
+	else if (!ast_park_call(transferee, transferer, 0, NULL)) {
+
+		if (transferer == peer)
+			res = AST_PBX_KEEPALIVE;
+ 		else
+			res = AST_PBX_NO_HANGUP_PEER;
+		return res;
+	} else {
+		ast_log(LOG_WARNING, "Unable to park call %s\n", transferee->name); 
+	} 
+
+	if (!ast_strlen_zero(xferfailsound))
+		res = ast_streamfile(transferer, xferfailsound, transferee->language);
+	else
+		res = 0;
+	if (res) {
+		ast_moh_stop(transferee);
+		ast_autoservice_stop(transferee);
+		ast_indicate(transferee, AST_CONTROL_UNHOLD);
+		return res;
+	}
+	res = ast_waitstream(transferer, AST_DIGIT_ANY);
+	ast_stopstream(transferer);
+	ast_moh_stop(transferee);
+	res = ast_autoservice_stop(transferee);
+	ast_indicate(transferee, AST_CONTROL_UNHOLD);
+	if (res) {
+		if (option_verbose > 1)
+			ast_verbose(VERBOSE_PREFIX_2 "Hungup during autoservice stop on '%s'\n", transferee->name);
+		return res;
+	}
+	return FEATURE_RETURN_SUCCESS;
+}
+
 static int builtin_atxfer(struct ast_channel *chan, struct ast_channel *peer, struct ast_bridge_config *config, char *code, int sense)
 {
 	struct ast_channel *transferer;
@@ -863,6 +951,7 @@
 	{ AST_FEATURE_REDIRECT, "Attended Transfer", "atxfer", "", "", builtin_atxfer, AST_FEATURE_FLAG_NEEDSDTMF },
 	{ AST_FEATURE_AUTOMON, "One Touch Monitor", "automon", "", "", builtin_automonitor, AST_FEATURE_FLAG_NEEDSDTMF },
 	{ AST_FEATURE_DISCONNECT, "Disconnect Call", "disconnect", "*", "*", builtin_disconnect, AST_FEATURE_FLAG_NEEDSDTMF },
+	{ AST_FEATURE_REDIRECT, "One Touch Park", "autopark", "", "", builtin_autopark, AST_FEATURE_FLAG_NEEDSDTMF },
 };
 
 
